==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_results/mp0058_001/MP0058_SyncWorkOrderSchedule_001_Result.java <==

package net.datastream.schemas.mp_results.mp0058_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.WOSCHEDULEID;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULEID"/>
 *                   &lt;element name="CONFLICT">
 *                     &lt;simpleType>
 *                       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *                         &lt;enumeration value="none"/>
 *                         &lt;enumeration value="both"/>
 *                         &lt;enumeration value="equipment"/>
 *                         &lt;enumeration value="employee"/>
 *                       &lt;/restriction>
 *                     &lt;/simpleType>
 *                   &lt;/element>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0058_SyncWorkOrderSchedule_001_Result")
public class MP0058_SyncWorkOrderSchedule_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP0058_SyncWorkOrderSchedule_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP0058_SyncWorkOrderSchedule_001_Result.ResultData }
     *     
     */
    public MP0058_SyncWorkOrderSchedule_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP0058_SyncWorkOrderSchedule_001_Result.ResultData }
     *     
     */
    public void setResultData(MP0058_SyncWorkOrderSchedule_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULEID"/>
     *         &lt;element name="CONFLICT">
     *           &lt;simpleType>
     *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
     *               &lt;enumeration value="none"/>
     *               &lt;enumeration value="both"/>
     *               &lt;enumeration value="equipment"/>
     *               &lt;enumeration value="employee"/>
     *             &lt;/restriction>
     *           &lt;/simpleType>
     *         &lt;/element>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "woscheduleid",
        "conflict"
    })
    public static class ResultData {

        @XmlElement(name = "WOSCHEDULEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected WOSCHEDULEID woscheduleid;
        @XmlElement(name = "CONFLICT", required = true, defaultValue = "none")
        protected String conflict;

        /**
         * Obtient la valeur de la propriété woscheduleid.
         * 
         * @return
         *     possible object is
         *     {@link WOSCHEDULEID }
         *     
         */
        public WOSCHEDULEID getWOSCHEDULEID() {
            return woscheduleid;
        }

        /**
         * Définit la valeur de la propriété woscheduleid.
         * 
         * @param value
         *     allowed object is
         *     {@link WOSCHEDULEID }
         *     
         */
        public void setWOSCHEDULEID(WOSCHEDULEID value) {
            this.woscheduleid = value;
        }

        /**
         * Obtient la valeur de la propriété conflict.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCONFLICT() {
            return conflict;
        }

        /**
         * Définit la valeur de la propriété conflict.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCONFLICT(String value) {
            this.conflict = value;
        }

    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_results/mp0058_001/MP0058_SyncWorkOrderSchedule_001_Result.java <==

package net.datastream.schemas.mp_results.mp0058_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.WOSCHEDULEID;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULEID"/>
 *                   &lt;element name="CONFLICT">
 *                     &lt;simpleType>
 *                       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *                         &lt;enumeration value="none"/>
 *                         &lt;enumeration value="both"/>
 *                         &lt;enumeration value="equipment"/>
 *                         &lt;enumeration value="employee"/>
 *                       &lt;/restriction>
 *                     &lt;/simpleType>
 *                   &lt;/element>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0058_SyncWorkOrderSchedule_001_Result")
public class MP0058_SyncWorkOrderSchedule_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP0058_SyncWorkOrderSchedule_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP0058_SyncWorkOrderSchedule_001_Result.ResultData }
     *     
     */
    public MP0058_SyncWorkOrderSchedule_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP0058_SyncWorkOrderSchedule_001_Result.ResultData }
     *     
     */
    public void setResultData(MP0058_SyncWorkOrderSchedule_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULEID"/>
     *         &lt;element name="CONFLICT">
     *           &lt;simpleType>
     *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
     *               &lt;enumeration value="none"/>
     *               &lt;enumeration value="both"/>
     *               &lt;enumeration value="equipment"/>
     *               &lt;enumeration value="employee"/>
     *             &lt;/restriction>
     *           &lt;/simpleType>
     *         &lt;/element>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "woscheduleid",
        "conflict"
    })
    public static class ResultData {

        @XmlElement(name = "WOSCHEDULEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected WOSCHEDULEID woscheduleid;
        @XmlElement(name = "CONFLICT", required = true, defaultValue = "none")
        protected String conflict;

        /**
         * Gets the value of the woscheduleid property.
         * 
         * @return
         *     possible object is
         *     {@link WOSCHEDULEID }
         *     
         */
        public WOSCHEDULEID getWOSCHEDULEID() {
            return woscheduleid;
        }

        /**
         * Sets the value of the woscheduleid property.
         * 
         * @param value
         *     allowed object is
         *     {@link WOSCHEDULEID }
         *     
         */
        public void setWOSCHEDULEID(WOSCHEDULEID value) {
            this.woscheduleid = value;
        }

        /**
         * Gets the value of the conflict property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCONFLICT() {
            return conflict;
        }

        /**
         * Sets the value of the conflict property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCONFLICT(String value) {
            this.conflict = value;
        }

    }

}
